searchData={"items":[{"type":"module","title":"Injexor","doc":"Injexor provides an easy way to replace modules based on behaviours\nfor mocking during tests or stubbing in another module based on config.\n\nThis allows go to definition and auto complete to continue to function for dev.\n\nSpecified modules are only replaced in function calls that are defined as a callback.\n\nThere are two ways to define an injected module, first is by using the `:inject` opt passed to `use`.\nIt can be either a single module or a list.\n\n```\nuse Injexor, inject: MyApp.Repo\nuse Injexor, inject: [MyApp.Repo, MyApp.Repo]\n```\n\nYou can also explicitly tell it what behaviour to use in the case where a module may have many.\n\n```\nuse Injexor, inject: {MyApp.Repo, MyApp.Repo.Behaviour}\n```\n\nThe other way is to define `@inject` attribute above a function def. `@inject` also accepts either\na single module or a list. This should only be used when you want to affect a single function.\n\n```\nuse Injexor\n\nalias MyApp.Repo\n\n@inject Repo\ndef get(id) do\n  Repo.get(id)\nend\n```\n\nThen you can call the module as normal in your code and use mox/hammox in your tests.\n\nFor example for `use Injexor, inject: MyApp.Repo`, the macro will lookup the module\nto inject with `Application.get_env(:injexor, MyApp.Repo)[:inject]`.\n\nExample config\n\n```\nconfig :injexor, MyApp.Repo, inject: MyApp.Repo.Mock\n```\n\nYou can altneratively setup a default that will be appended to all modules.\n\n```\nconfig :injexor, :default, Mock\n```\n\nIf none of the above are set, the module itself will be used.","ref":"Injexor.html"},{"type":"extras","title":"Injexor","doc":"# Injexor\n\nInjexor provides an easy way to replace modules based on behaviours\nfor mocking during tests or stubbing in another module based on\nconfig for different environments.\n\nSee the docs for full instructions: https://hexdocs.pm/injexor","ref":"readme.html"},{"type":"extras","title":"Installation - Injexor","doc":"The package can be installed by adding `injexor` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:injexor, \"~> 1.0.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Example test configuration: - Injexor","doc":"- test.exs\n\n    ```elixir\n    config :injexor, default: Mock # adds Mock on the end of all modules by default\n\n    # or you can alternatively register injects manually\n    config :injexor, MyApp.MyBehaviour, inject: MyApp.Mock\n    ```\n\n- test_helper.exs\n\n    ```elixir\n    Hammox.defmock(MyApp.Mock, for: MyApp.MyBehaviour)\n    ```\n\n- lib/my_app.ex\n\n    ```elixir\n    defmodule MyApp do\n      @behaviour MyApp.MyBehaviour\n\n      def deploy_context() do\n        Application.fetch_env!(:my_app, :deploy_context)\n      end\n    end\n    ```\n\n- lib/my_app/my_behaviour.ex\n\n    ```elixir\n    defmodule  MyApp.MyBehaviour do\n      @callback deploy_context() :: atom()\n    end\n    ```\n\n- lib/my_app/module.ex\n\n    ```elixir\n    defmodule MyApp.Module do\n      use Injexor, inject: [MyApp]\n\n      def my_function do\n        # you can now use mox/hammox to stub/expect this function to test the different paths\n        if MyApp.deploy_context() == \"production\" do\n          # do something\n        else\n          # do something else\n        end\n      end\n    end\n    ```","ref":"readme.html#example-test-configuration"},{"type":"extras","title":"Changelog","doc":"1.0.0\n------\n#### Changes\n- Now evaluates modules to inject at runtime\n- Supports passing :default option that will be appended to modules to automatically inject to make test config simpler\n\n0.1.0\n------\n#### Changes\n- First version","ref":"changelog.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,51,46,48]}}